@@ -115,7 +115,6 @@ KCModuleQml::KCModuleQml(std::unique_ptr<KQuickAddons::ConfigModule> configModul
     d->quickWidget = new QQuickWidget(d->qmlObject->engine(), this);
     d->quickWidget->setResizeMode(QQuickWidget::SizeRootObjectToView);
     d->quickWidget->setFocusPolicy(Qt::StrongFocus);
-    d->quickWidget->installEventFilter(this);
     d->quickWidget->setAttribute(Qt::WA_AlwaysStackOnTop, true);
     d->quickWindow = d->quickWidget->quickWindow();
     d->quickWindow->setColor(Qt::transparent);
@@ -127,38 +126,58 @@ KCModuleQml::KCModuleQml(std::unique_ptr<KQuickAddons::ConfigModule> configModul
     //because its parameters are QQmlV4Function which is not public
     //the managers of onEnter/ReturnPressed are a workaround of
     //Qt bug https://bugreports.qt.io/browse/QTBUG-70934
-    component->setData(QByteArrayLiteral("import QtQuick 2.3\n"
-        "import org.kde.kirigami 2.4 as Kirigami\n"
-        "import QtQuick.Window 2.2\n"
-        "Kirigami.ApplicationItem{"
-            //force it to *never* try to resize itself
-            "width: Window.width;"
-            //purely cosmetic space, those magic values are to align perfectly within Systemsettings
-            "header: Item {height: Math.round(Kirigami.Units.gridUnit*0.25)}"
-            "implicitWidth:pageStack.implicitWidth;"
-            "implicitHeight:pageStack.implicitHeight+header.height;"
-            // allow only one column by default
-            "pageStack.defaultColumnWidth:width;"
-            "pageStack.separatorVisible:false;"
-            "pageStack.globalToolBar.style: pageStack.wideScreen ? Kirigami.ApplicationHeaderStyle.Titles : Kirigami.ApplicationHeaderStyle.Breadcrumb;"
-            "pageStack.globalToolBar.showNavigationButtons:true;"
-            "pageStack.globalToolBar.separatorVisible:false;"
-            "activeFocusOnTab:true;"
-            "Keys.onReturnPressed:{event.accepted=true}"
-            "Keys.onEnterPressed:{event.accepted=true}"
-        "}"), QUrl());
+    component->setData(QByteArrayLiteral(R"(
+import QtQuick 2.3
+import QtQuick.Window 2.2
+import QtQuick.Controls 2.2
+import org.kde.kirigami 2.4 as Kirigami
+
+Kirigami.ApplicationItem {
+    //force it to *never* try to resize itself
+    width: Window.width
+
+    implicitWidth: pageStack.implicitWidth
+    implicitHeight: pageStack.implicitHeight
+
+    activeFocusOnTab: true
+    controlsVisible: false
+
+    ToolButton {
+        id:toolButton
+        visible: false
+        icon.name: "go-previous"
+    }
+
+    pageStack.separatorVisible: false
+    pageStack.globalToolBar.preferredHeight: toolButton.implicitHeight + Kirigami.Units.smallSpacing * 2
+    pageStack.globalToolBar.style: pageStack.wideScreen ? Kirigami.ApplicationHeaderStyle.Titles : Kirigami.ApplicationHeaderStyle.Breadcrumb
+    pageStack.globalToolBar.showNavigationButtons: true
+
+    Keys.onReturnPressed: {
+        event.accepted = true
+    }
+    Keys.onEnterPressed: {
+        event.accepted = true
+    }
+}
+    )"), QUrl());
 
     d->rootPlaceHolder = qobject_cast<QQuickItem *>(component->create());
     if (!d->rootPlaceHolder) {
         qCCritical(KCMUTILS_LOG) << component->errors();
         qFatal("Failed to intiailize KCModuleQML");
     }
+    d->rootPlaceHolder->installEventFilter(this);
     d->quickWidget->setContent(QUrl(), component, d->rootPlaceHolder);
 
     d->pageRow = d->rootPlaceHolder->property("pageStack").value<QQuickItem *>();
     if (d->pageRow) {
         QMetaObject::invokeMethod(d->pageRow, "push", Qt::DirectConnection, Q_ARG(QVariant, QVariant::fromValue(d->configModule->mainUi())), Q_ARG(QVariant, QVariant()));
 
+        for (int i = 0 ; i < d->configModule->depth() -1 ; i++) {
+                QMetaObject::invokeMethod(d->pageRow, "push", Qt::DirectConnection, Q_ARG(QVariant, QVariant::fromValue(d->configModule->subPage(i))), Q_ARG(QVariant, QVariant()));
+        }
+
         connect(d->configModule.get(), &KQuickAddons::ConfigModule::pagePushed, this, [this](QQuickItem *page) {
                 QMetaObject::invokeMethod(d->pageRow, "push", Qt::DirectConnection, Q_ARG(QVariant, QVariant::fromValue(page)), Q_ARG(QVariant, QVariant()));
             }
@@ -188,20 +207,6 @@ KCModuleQml::KCModuleQml(std::unique_ptr<KQuickAddons::ConfigModule> configModul
         connect(d->rootPlaceHolder, &QQuickItem::widthChanged,
                 this, syncColumnWidth);
 
-        //HACK: in order to work with old Systemsettings
-        //search if we are in a KPageWidget, search ofr its page, and if it has
-        //an header set, disable our own title
-        //FIXME: eventually remove this hack
-        QObject *candidate = this;
-        while (candidate) {
-            candidate = candidate->parent();
-            KPageWidget *page = qobject_cast<KPageWidget *>(candidate);
-            if (page && !page->currentPage()->header().isEmpty()) {
-                QObject *globalToolBar = d->pageRow->property("globalToolBar").value<QObject *>();
-                //5 is None
-                globalToolBar->setProperty("style", 5);
-            }
-        }
     }
     
     layout->addWidget(d->quickWidget);
@@ -214,48 +219,21 @@ KCModuleQml::~KCModuleQml()
 
 bool KCModuleQml::eventFilter(QObject* watched, QEvent* event)
 {
-    //FIXME: those are all workarounds around the QQuickWidget brokeness
-    //BUG https://bugreports.qt.io/browse/QTBUG-64561
-    if (watched == d->quickWidget && event->type() == QEvent::KeyPress) {
-        //allow tab navigation inside the qquickwidget
-        QKeyEvent *ke = static_cast<QKeyEvent *>(event);
-
-        QQuickItem *currentItem = d->quickWindow->activeFocusItem();
-        if (!currentItem) {
-            return KCModule::eventFilter(watched, event);
-        }
-        if (currentItem->scopedFocusItem()) {
-            currentItem = currentItem->scopedFocusItem();
-        }
-
-        if (ke->key() == Qt::Key_Tab) {
-            //nextItemInFocusChain will always return something, in the worst case will still be currentItem
-            QQuickItem *nextItem = currentItem->nextItemInFocusChain(true);
-            //when it arrives at the place holder item, go out of the qqw and
-            //go to the other widgets around systemsettigns
-            if (nextItem == d->rootPlaceHolder) {
-                QWidget *w = d->quickWidget->nextInFocusChain();
-                while (!w->isEnabled() || !(w->focusPolicy() & Qt::TabFocus)) {
-                    w = w->nextInFocusChain();
+    if (watched == d->rootPlaceHolder && event->type() == QEvent::FocusIn) {
+        auto focusEvent = static_cast<QFocusEvent*>(event);
+        if (focusEvent->reason() == Qt::TabFocusReason) {
+            QWidget *w = d->quickWidget->nextInFocusChain();
+               while (!w->isEnabled() || !(w->focusPolicy() & Qt::TabFocus)) {
+                   w = w->nextInFocusChain();
                 }
-                w->setFocus(Qt::TabFocusReason);
-            } else {
-                nextItem->forceActiveFocus(Qt::TabFocusReason);
-            }
-            return true;
-        } else if (ke->key() == Qt::Key_Backtab
-                   || (ke->key() == Qt::Key_Tab && (ke->modifiers() & Qt::ShiftModifier))) {
-            QQuickItem *nextItem = currentItem->nextItemInFocusChain(false);
-
-            if (nextItem == d->rootPlaceHolder) {
-                QWidget *w = d->quickWidget->previousInFocusChain();
-                while (!w->isEnabled() || !(w->focusPolicy() & Qt::TabFocus)) {
-                    w = w->previousInFocusChain();
-                }
-                w->setFocus(Qt::BacktabFocusReason);
-            } else {
-                nextItem->forceActiveFocus(Qt::BacktabFocusReason);
+                w->setFocus(Qt::TabFocusReason);        //allow tab navigation inside the qquickwidget
+                return true;
+        } else if (focusEvent->reason() == Qt::BacktabFocusReason) {
+            QWidget *w = d->quickWidget->previousInFocusChain();
+            while (!w->isEnabled() || !(w->focusPolicy() & Qt::TabFocus)) {
+                w = w->previousInFocusChain();
             }
+            w->setFocus(Qt::BacktabFocusReason);
             return true;
         }
     }
