@@ -1,34 +1,23 @@
-/**
-  * This file is part of the KDE project
-  * Copyright (C) 2007, 2006 Rafael Fernández López <ereslibre@kde.org>
-  * Copyright (C) 2002-2003 Matthias Kretz <kretz@kde.org>
-  *
-  * This library is free software; you can redistribute it and/or
-  * modify it under the terms of the GNU Library General Public
-  * License version 2 as published by the Free Software Foundation.
-  *
-  * This library is distributed in the hope that it will be useful,
-  * but WITHOUT ANY WARRANTY; without even the implied warranty of
-  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  * Library General Public License for more details.
-  *
-  * You should have received a copy of the GNU Library General Public License
-  * along with this library; see the file COPYING.LIB.  If not, write to
-  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  * Boston, MA 02110-1301, USA.
-  */
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007, 2006 Rafael Fernández López <ereslibre@kde.org>
+    SPDX-FileCopyrightText: 2002-2003 Matthias Kretz <kretz@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #ifndef KPLUGINSELECTOR_H
 #define KPLUGINSELECTOR_H
 
 #include <QWidget>
 
-#include <QtCore/QList>
+#include <QList>
 
 #include <kcmutils_export.h>
-#include <ksharedconfig.h>
+#include <KSharedConfig>
 
 class KPluginInfo;
+class QPushButton;
 
 /**
   * @short A widget to select what plugins to load and configure the plugins.
@@ -36,7 +25,7 @@ class KPluginInfo;
   * It shows the list of available plugins
   *
   * Since the user needs a way to know what a specific plugin does every plugin
-  * sould install a desktop file containing a name, comment and category field.
+  * should install a desktop file containing a name, comment and category field.
   * The category is useful for applications that can use different kinds of
   * plugins like a playlist, skin or visualization
   *
@@ -152,6 +141,12 @@ public:
                     const QString &categoryKey = QString(),
                     const KSharedConfig::Ptr &config = KSharedConfig::Ptr());
 
+    /**
+     * Remove all plugins from the entry list.
+     * @since 5.73
+     */
+    void clearPlugins();
+
     /**
       * Load the state of the plugins (selected or not) from the KPluginInfo
       * objects
@@ -163,6 +158,13 @@ public:
       */
     void save();
 
+    /**
+     * Returns true if the plugin selector has any changes that are not yet saved to configuration.
+     * @see save()
+     * @since 5.78
+     */
+    bool isSaveNeeded() const;
+
     /**
       * Change to applications defaults
       * @see isDefault()
@@ -209,6 +211,28 @@ public:
      */
     QStringList configurationArguments() const;
 
+    /**
+     * Shows the configuration dialog for the plugin @p pluginId if it's available
+     *
+     * @since 5.45
+     */
+    void showConfiguration(const QString &pluginId);
+
+    /**
+     * Add additional widgets to each row of the plugin selector
+     * @param handler returns the additional button that should be displayed in the row
+     * the handler can return a null pointer if no button should be displayed
+     * @since 5.74
+     */
+    void setAdditionalButtonHandler(std::function<QPushButton*(const KPluginInfo &)> handler);
+
+    /**
+     * Show an indicator when a plugin status is different from default
+     *
+     * @since 5.78
+     */
+    void setDefaultsIndicatorsVisible(bool isVisible);
+
 Q_SIGNALS:
     /**
       * Tells you whether the configuration is changed or not.
@@ -222,6 +246,20 @@ Q_SIGNALS:
       */
     void configCommitted(const QByteArray &componentName);
 
+    /**
+      * Emitted after configuration is changed, tell if configuration represent default or not
+      * @since 5.67
+     */
+    void defaulted(bool isDefault);
+
+    /**
+     * Emitted when show defaults indicators changed
+     * @see setDefaultsIndicatorsVisible
+     *
+     * @since 5.78
+     */
+    void defaultsIndicatorsVisible();
+
 private:
     class Private;
     Private *const d;
